pub struct SettingsState {Show 48 fields
pub selected: usize,
pub tab: SettingsTab,
pub model: String,
pub model_options: Vec<String>,
pub chosen_models: Vec<String>,
pub theme_name: String,
pub theme_options: Vec<String>,
pub thinking_level: ThinkingLevel,
pub max_tokens: u32,
pub max_turns: u32,
pub observation_mask: f64,
pub sidebar_style: SidebarStyle,
pub tool_output: ToolOutputDisplay,
pub tool_output_lines: usize,
pub read_max_lines: usize,
pub sidebar_width: u16,
pub word_wrap: bool,
pub animations: AnimationLevel,
pub chat_tool_display: ChatToolDisplay,
pub auto_open_sidebar: bool,
pub sidebar_auto_open_width: u16,
pub thinking_lines: usize,
pub streaming_lines: usize,
pub mouse_scroll_lines: usize,
pub keyboard_scroll_lines: usize,
pub show_timestamps: bool,
pub show_cost: bool,
pub show_context_usage: bool,
pub notify_on_agent_complete: bool,
pub continue_policy: ContinuePolicy,
pub improve_auto_turn_budget: u32,
pub loop_turn_budget: u32,
pub web_search_provider: Option<SearchProvider>,
pub mana_scope: ManaScopePreference,
pub mana_auto_commit: bool,
pub mana_auto_close_parent: bool,
pub mana_verify_timeout: u64,
pub mana_run_background: bool,
pub mana_max_workers: u32,
pub mana_review_after_run: bool,
pub mana_continue_after_failure: bool,
pub tavily_api_key: String,
pub exa_api_key: String,
pub tavily_configured: bool,
pub exa_configured: bool,
pub editing_number: bool,
pub edit_buffer: String,
pub dirty: bool,
}Expand description
State for the settings overlay.
Fields
selected: usizetab: SettingsTabmodel: Stringmodel_options: Vec<String>chosen_models: Vec<String>theme_name: Stringtheme_options: Vec<String>thinking_level: ThinkingLevelmax_tokens: u32max_turns: u32observation_mask: f64tool_output: ToolOutputDisplaytool_output_lines: usizeread_max_lines: usizeword_wrap: boolanimations: AnimationLevelchat_tool_display: ChatToolDisplaythinking_lines: usizestreaming_lines: usizemouse_scroll_lines: usizekeyboard_scroll_lines: usizeshow_timestamps: boolshow_cost: boolshow_context_usage: boolnotify_on_agent_complete: boolcontinue_policy: ContinuePolicyimprove_auto_turn_budget: u32loop_turn_budget: u32web_search_provider: Option<SearchProvider>mana_scope: ManaScopePreferencemana_auto_commit: boolmana_auto_close_parent: boolmana_verify_timeout: u64mana_run_background: boolmana_max_workers: u32mana_review_after_run: boolmana_continue_after_failure: booltavily_api_key: Stringexa_api_key: Stringtavily_configured: boolexa_configured: boolediting_number: booledit_buffer: Stringdirty: boolImplementations
Sourceimpl SettingsState
impl SettingsState
pub fn switch_tab_forward(&mut self)
pub fn switch_tab_backward(&mut self)
pub fn new( config: &Config, model_name: &str, models: &[ModelMeta], auth_store: &AuthStore, ) -> Self
pub fn current_field(&self) -> SettingsField
pub fn move_up(&mut self)
pub fn move_down(&mut self)
Sourcepub fn cycle_forward(&mut self)
pub fn cycle_forward(&mut self)
Cycle the current field’s value forward.
Sourcepub fn cycle_backward(&mut self)
pub fn cycle_backward(&mut self)
Cycle the current field’s value backward.
Sourcepub fn start_edit(&mut self)
pub fn start_edit(&mut self)
Begin direct numeric input for the current field.
pub fn push_char(&mut self, c: char)
pub fn pop_char(&mut self)
Sourcepub fn commit_edit(&mut self)
pub fn commit_edit(&mut self)
Commit the edit buffer to the underlying field value.
Sourcepub fn apply_to_config(&self, config: &mut Config)
pub fn apply_to_config(&self, config: &mut Config)
Write current settings into a Config for saving and in-session use.