pub fn render_markdown_with_width<'a>(
text: &str,
theme: &Theme,
highlighter: &Highlighter,
width: usize,
) -> Vec<Line<'a>>Expand description
Render markdown while constraining tables to a target content width.
This is primarily used by the chat view so markdown tables can wrap inside the available pane width instead of being broken by outer line wrapping.